@@ -13,7 +13,7 @@ use HTTP::Date;
 use HTTP::Status qw{ :constants };
 use Test::More 0.96;	# For subtest
 
-our $VERSION = '0.161_01';
+our $VERSION = '0.162_01';
 
 # Set the following to zero if Space Track (or any other SSL host)
 # starts using a certificate that can not be verified.
@@ -195,7 +195,8 @@ sub not_defined {
 		url	=> 'https://celestrak.org/',
 	    },
 	    'mike.mccants'	=> {
-		url	=> 'http://www.prismnet.com/~mmccants/',
+		# url	=> 'http://www.prismnet.com/~mmccants/',
+		url	=> 'https://www.mmccants.org/',
 	    },
 	    'rod.sladen'	=> {
 		url	=> 'http://www.rod.sladen.org.uk/iridium.htm',
